==> zio-aws-schemas_2.13-5.17.124.3-sources.jar: zio/aws/schemas/model/StartDiscovererRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class StartDiscovererRequest(discovererId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.StartDiscovererRequest = {
    import StartDiscovererRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.StartDiscovererRequest
      .builder()
      .discovererId(__string.unwrap(discovererId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.StartDiscovererRequest.ReadOnly =
    zio.aws.schemas.model.StartDiscovererRequest.wrap(buildAwsValue())
}
object StartDiscovererRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.StartDiscovererRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.StartDiscovererRequest =
      zio.aws.schemas.model.StartDiscovererRequest(discovererId)
    def discovererId: __string
    def getDiscovererId: ZIO[Any, Nothing, __string] = ZIO.succeed(discovererId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.StartDiscovererRequest
  ) extends zio.aws.schemas.model.StartDiscovererRequest.ReadOnly {
    override val discovererId: __string =
      zio.aws.schemas.model.primitives.__string(impl.discovererId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.StartDiscovererRequest
  ): zio.aws.schemas.model.StartDiscovererRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-schemas_2.13-5.17.149.1-sources.jar: zio/aws/schemas/model/StartDiscovererRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class StartDiscovererRequest(discovererId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.StartDiscovererRequest = {
    import StartDiscovererRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.StartDiscovererRequest
      .builder()
      .discovererId(discovererId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.StartDiscovererRequest.ReadOnly =
    zio.aws.schemas.model.StartDiscovererRequest.wrap(buildAwsValue())
}
object StartDiscovererRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.StartDiscovererRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.StartDiscovererRequest =
      zio.aws.schemas.model.StartDiscovererRequest(discovererId)
    def discovererId: __string
    def getDiscovererId: ZIO[Any, Nothing, __string] = ZIO.succeed(discovererId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.StartDiscovererRequest
  ) extends zio.aws.schemas.model.StartDiscovererRequest.ReadOnly {
    override val discovererId: __string = impl.discovererId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.StartDiscovererRequest
  ): zio.aws.schemas.model.StartDiscovererRequest.ReadOnly = new Wrapper(impl)
}
